@@ -5,11 +5,10 @@ import os
 import random
 
 import re
-from time import time
+import time
 
 import requests
 
-from dbstream.tools.dck_infos import generate_dck_info
 from dbstream.tools.parse_data import treat_json_data
 from dbstream.tools.regex import replace_query_details
 from dbstream.tunnel import create_ssh_tunnel
@@ -23,8 +22,8 @@ class DBStream:
         self.ssh_init_port = ""
         self.client_id = client_id
         self.ssh_tunnel = None
-        self.dbstream_instance_id = 'df-' + datetime.datetime.now().strftime('%s') + '-' + str(
-            random.randint(1000, 9999))
+        unix_time = time.mktime(datetime.datetime.now().timetuple())
+        self.dbstream_instance_id = 'df-' + str(unix_time) + '-' + str(random.randint(1000, 9999))
         self.special_env = special_env if special_env else None
 
     def error_if_function_not_exist(self, function_name):
@@ -103,6 +102,7 @@ class DBStream:
         pass
 
     def send_data(self, data, replace=True, apply_special_env=True, **kwargs):
+        data["columns_name"] = [c.replace(".", "_") for c in data["columns_name"]]
         data_copy = copy.deepcopy(data)
         if apply_special_env and self.special_env:
             schema_name = data_copy["table_name"].split(".")[0]
